Class: CheckoutSdk::Accounts::OnboardEntity

Inherits:
Object
  • Object
show all
Defined in:
lib/checkout_sdk/accounts/onboard_entity.rb

Instance Attribute Summary collapse

Instance Attribute Details

#additional_infoAdditionalInfo

Returns:



32
33
34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32

class OnboardEntity
  attr_accessor :reference,
                :is_draft,
                :profile,
                :contact_details,
                :company,
                :processing_details,
                :individual,
                :documents,
                :additional_info,
                :seller_category,
                :agreed_terms,
                :submitter
end

#agreed_termsAgreedTerms

Returns Details of the person who agreed to the terms and conditions (Accounts API v3.0 SaaS onboarding).

Returns:

  • (AgreedTerms)

    Details of the person who agreed to the terms and conditions (Accounts API v3.0 SaaS onboarding).



32
33
34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32

class OnboardEntity
  attr_accessor :reference,
                :is_draft,
                :profile,
                :contact_details,
                :company,
                :processing_details,
                :individual,
                :documents,
                :additional_info,
                :seller_category,
                :agreed_terms,
                :submitter
end

#companyCompany

Returns:



32
33
34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32

class OnboardEntity
  attr_accessor :reference,
                :is_draft,
                :profile,
                :contact_details,
                :company,
                :processing_details,
                :individual,
                :documents,
                :additional_info,
                :seller_category,
                :agreed_terms,
                :submitter
end

#contact_detailsContactDetails

Returns:



32
33
34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32

class OnboardEntity
  attr_accessor :reference,
                :is_draft,
                :profile,
                :contact_details,
                :company,
                :processing_details,
                :individual,
                :documents,
                :additional_info,
                :seller_category,
                :agreed_terms,
                :submitter
end

#documentsOnboardSubEntityDocuments



32
33
34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32

class OnboardEntity
  attr_accessor :reference,
                :is_draft,
                :profile,
                :contact_details,
                :company,
                :processing_details,
                :individual,
                :documents,
                :additional_info,
                :seller_category,
                :agreed_terms,
                :submitter
end

#individualIndividual

Returns:



32
33
34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32

class OnboardEntity
  attr_accessor :reference,
                :is_draft,
                :profile,
                :contact_details,
                :company,
                :processing_details,
                :individual,
                :documents,
                :additional_info,
                :seller_category,
                :agreed_terms,
                :submitter
end

#is_draftBoolean

Returns:

  • (Boolean)


32
33
34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32

class OnboardEntity
  attr_accessor :reference,
                :is_draft,
                :profile,
                :contact_details,
                :company,
                :processing_details,
                :individual,
                :documents,
                :additional_info,
                :seller_category,
                :agreed_terms,
                :submitter
end

#processing_detailsProcessingDetails

Returns:



32
33
34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32

class OnboardEntity
  attr_accessor :reference,
                :is_draft,
                :profile,
                :contact_details,
                :company,
                :processing_details,
                :individual,
                :documents,
                :additional_info,
                :seller_category,
                :agreed_terms,
                :submitter
end

#profileProfile

Returns:



32
33
34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32

class OnboardEntity
  attr_accessor :reference,
                :is_draft,
                :profile,
                :contact_details,
                :company,
                :processing_details,
                :individual,
                :documents,
                :additional_info,
                :seller_category,
                :agreed_terms,
                :submitter
end

#referenceString

Returns:

  • (String)


32
33
34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32

class OnboardEntity
  attr_accessor :reference,
                :is_draft,
                :profile,
                :contact_details,
                :company,
                :processing_details,
                :individual,
                :documents,
                :additional_info,
                :seller_category,
                :agreed_terms,
                :submitter
end

#seller_categoryString

Returns Identifier of a seller category configured on the platform during onboarding. Used for US ISV onboarding variants.

Returns:

  • (String)

    Identifier of a seller category configured on the platform during onboarding. Used for US ISV onboarding variants.



32
33
34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32

class OnboardEntity
  attr_accessor :reference,
                :is_draft,
                :profile,
                :contact_details,
                :company,
                :processing_details,
                :individual,
                :documents,
                :additional_info,
                :seller_category,
                :agreed_terms,
                :submitter
end

#submitterSubmitter

Returns Captures evidence of the end-user's consent to onboarding. Used for US ISV onboarding variants.

Returns:

  • (Submitter)

    Captures evidence of the end-user's consent to onboarding. Used for US ISV onboarding variants.



32
33
34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32

class OnboardEntity
  attr_accessor :reference,
                :is_draft,
                :profile,
                :contact_details,
                :company,
                :processing_details,
                :individual,
                :documents,
                :additional_info,
                :seller_category,
                :agreed_terms,
                :submitter
end