Class: CheckoutSdk::Accounts::ScheduleFrequencyMonthly

Inherits:
ScheduleRequest show all
Defined in:
lib/checkout_sdk/accounts/schedule_frequency_monthly.rb

Instance Attribute Summary collapse

Attributes inherited from ScheduleRequest

#frequency

Instance Method Summary collapse

Constructor Details

#initializeScheduleFrequencyMonthly

Returns a new instance of ScheduleFrequencyMonthly.



12
13
14
# File 'lib/checkout_sdk/accounts/schedule_frequency_monthly.rb', line 12

def initialize
  super(ScheduleFrequencyType::MONTHLY)
end

Instance Attribute Details

#by_month_dayArray(Integer)

Returns The day or days of the month the payout should take place. For SaaS sellers (ISV), only the following combinations are supported, in any order: [1], [15], [1, 15] or [1, 16].

Returns:

  • (Array(Integer))

    The day or days of the month the payout should take place. For SaaS sellers (ISV), only the following combinations are supported, in any order: [1], [15], [1, 15] or [1, 16].



9
10
11
12
13
14
15
# File 'lib/checkout_sdk/accounts/schedule_frequency_monthly.rb', line 9

class ScheduleFrequencyMonthly < ScheduleRequest
  attr_accessor :by_month_day

  def initialize
    super(ScheduleFrequencyType::MONTHLY)
  end
end