Class: CheckoutSdk::Accounts::ScheduleFrequencyWeekly

Inherits:
ScheduleRequest show all
Defined in:
lib/checkout_sdk/accounts/schedule_frequency_weekly.rb

Instance Attribute Summary collapse

Attributes inherited from ScheduleRequest

#frequency

Instance Method Summary collapse

Constructor Details

#initializeScheduleFrequencyWeekly

Returns a new instance of ScheduleFrequencyWeekly.



12
13
14
# File 'lib/checkout_sdk/accounts/schedule_frequency_weekly.rb', line 12

def initialize
  super(ScheduleFrequencyType::WEEKLY)
end

Instance Attribute Details

#by_dayArray(String)

Returns The day or days of the week the payout should take place. For SaaS sellers (ISV), only working days (Monday to Friday) are supported; payouts set to take place on weekends are rejected.

Returns:

  • (Array(String))

    The day or days of the week the payout should take place. For SaaS sellers (ISV), only working days (Monday to Friday) are supported; payouts set to take place on weekends are rejected.



9
10
11
12
13
14
15
# File 'lib/checkout_sdk/accounts/schedule_frequency_weekly.rb', line 9

class ScheduleFrequencyWeekly < ScheduleRequest
  attr_accessor :by_day

  def initialize
    super(ScheduleFrequencyType::WEEKLY)
  end
end