Class: CheckoutSdk::Balances::CollateralBreakdown
- Inherits:
-
Object
- Object
- CheckoutSdk::Balances::CollateralBreakdown
- Defined in:
- lib/checkout_sdk/balances/collateral_breakdown.rb
Overview
Breakdown of the funds held in the collateral balance.
Instance Attribute Summary collapse
-
#fixed_reserve ⇒ Integer
(required) The portion of the
collateralbalance held as a fixed reserve. -
#rolling_reserve ⇒ Integer
(required) The portion of the
collateralbalance held as a rolling reserve.
Instance Attribute Details
#fixed_reserve ⇒ Integer
Returns (required) The portion of the collateral balance held as a fixed reserve.
11 12 13 14 |
# File 'lib/checkout_sdk/balances/collateral_breakdown.rb', line 11 class CollateralBreakdown attr_accessor :fixed_reserve, :rolling_reserve end |
#rolling_reserve ⇒ Integer
Returns (required) The portion of the collateral balance held as a rolling reserve.
11 12 13 14 |
# File 'lib/checkout_sdk/balances/collateral_breakdown.rb', line 11 class CollateralBreakdown attr_accessor :fixed_reserve, :rolling_reserve end |