Class: CheckoutSdk::Balances::CurrencyAccountBalance

Inherits:
Object
  • Object
show all
Defined in:
lib/checkout_sdk/balances/currency_account_balance.rb

Overview

A single currency account’s balance details (swagger: CurrencyAccountBalance).

Instance Attribute Summary collapse

Instance Attribute Details

#balancesBalanceValues

Returns:



18
19
20
21
22
23
24
# File 'lib/checkout_sdk/balances/currency_account_balance.rb', line 18

class CurrencyAccountBalance
  attr_accessor :currency_account_id,
                :descriptor,
                :holding_currency,
                :balances_as_of,
                :balances
end

#balances_as_ofString

Returns UTC datetime (RFC 3339) reflecting when balance values were fetched.

Returns:

  • (String)

    UTC datetime (RFC 3339) reflecting when balance values were fetched.



18
19
20
21
22
23
24
# File 'lib/checkout_sdk/balances/currency_account_balance.rb', line 18

class CurrencyAccountBalance
  attr_accessor :currency_account_id,
                :descriptor,
                :holding_currency,
                :balances_as_of,
                :balances
end

#currency_account_idString

The unique identifier of the currency account (sub-account). Returned only when the request is made with ‘withCurrencyAccountId=true`.

Returns:

  • (String)

    The unique identifier of the currency account (sub-account). Returned only when the request is made with ‘withCurrencyAccountId=true`.



18
19
20
21
22
23
24
# File 'lib/checkout_sdk/balances/currency_account_balance.rb', line 18

class CurrencyAccountBalance
  attr_accessor :currency_account_id,
                :descriptor,
                :holding_currency,
                :balances_as_of,
                :balances
end

#descriptorString

Returns:

  • (String)


18
19
20
21
22
23
24
# File 'lib/checkout_sdk/balances/currency_account_balance.rb', line 18

class CurrencyAccountBalance
  attr_accessor :currency_account_id,
                :descriptor,
                :holding_currency,
                :balances_as_of,
                :balances
end

#holding_currencyString

Returns Common::Currency.

Returns:



18
19
20
21
22
23
24
# File 'lib/checkout_sdk/balances/currency_account_balance.rb', line 18

class CurrencyAccountBalance
  attr_accessor :currency_account_id,
                :descriptor,
                :holding_currency,
                :balances_as_of,
                :balances
end