Class: CheckoutSdk::Disputes::DisputesQueryFilter
- Inherits:
-
Common::DateRangeQueryFilter
- Object
- Common::DateRangeQueryFilter
- CheckoutSdk::Disputes::DisputesQueryFilter
- Defined in:
- lib/checkout_sdk/disputes/disputes_query_filter.rb
Instance Attribute Summary collapse
-
#entity_ids ⇒ String?
One or more comma-separated client entity IDs.
-
#id ⇒ String?
The unique identifier of the dispute.
-
#limit ⇒ Integer?
The number of results to return.
-
#payment_arn ⇒ String?
The acquirer reference number (ARN).
-
#payment_id ⇒ String?
The unique identifier of the payment.
-
#payment_mcc ⇒ String?
The merchant category code (MCC) of the payment (ISO 18245).
-
#payment_reference ⇒ String?
An optional reference (such as an order ID) that identifies the payment.
-
#processing_channel_ids ⇒ String?
One or more comma-separated processing channel IDs.
-
#segment_ids ⇒ String?
One or more comma-separated segment IDs.
-
#skip ⇒ Integer?
The number of results to skip.
-
#statuses ⇒ String?
One or more comma-separated statuses to filter by.
-
#sub_entity_ids ⇒ String?
One or more comma-separated sub-entity IDs.
-
#this_channel_only ⇒ TrueClass, ...
If true, only returns disputes for the channel associated with the secret key.
Attributes inherited from Common::DateRangeQueryFilter
Instance Attribute Details
#entity_ids ⇒ String?
One or more comma-separated client entity IDs. Works like a logical OR.
- Optional
-
Example: “ent_wxglze3wwywujg4nna5fb7ldli,ent_vkb5zcy64zoe3cwfmaqvqyqyku”
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/checkout_sdk/disputes/disputes_query_filter.rb', line 63 class DisputesQueryFilter < CheckoutSdk::Common::DateRangeQueryFilter attr_accessor :limit, :skip, :id, :statuses, :payment_id, :payment_reference, :payment_arn, :this_channel_only, :entity_ids, :sub_entity_ids, :processing_channel_ids, :segment_ids, :payment_mcc end |
#id ⇒ String?
The unique identifier of the dispute.
- Optional
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/checkout_sdk/disputes/disputes_query_filter.rb', line 63 class DisputesQueryFilter < CheckoutSdk::Common::DateRangeQueryFilter attr_accessor :limit, :skip, :id, :statuses, :payment_id, :payment_reference, :payment_arn, :this_channel_only, :entity_ids, :sub_entity_ids, :processing_channel_ids, :segment_ids, :payment_mcc end |
#limit ⇒ Integer?
The number of results to return.
- Optional
-
min 1, max 250, default 50
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/checkout_sdk/disputes/disputes_query_filter.rb', line 63 class DisputesQueryFilter < CheckoutSdk::Common::DateRangeQueryFilter attr_accessor :limit, :skip, :id, :statuses, :payment_id, :payment_reference, :payment_arn, :this_channel_only, :entity_ids, :sub_entity_ids, :processing_channel_ids, :segment_ids, :payment_mcc end |
#payment_arn ⇒ String?
The acquirer reference number (ARN).
- Optional
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/checkout_sdk/disputes/disputes_query_filter.rb', line 63 class DisputesQueryFilter < CheckoutSdk::Common::DateRangeQueryFilter attr_accessor :limit, :skip, :id, :statuses, :payment_id, :payment_reference, :payment_arn, :this_channel_only, :entity_ids, :sub_entity_ids, :processing_channel_ids, :segment_ids, :payment_mcc end |
#payment_id ⇒ String?
The unique identifier of the payment.
- Optional
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/checkout_sdk/disputes/disputes_query_filter.rb', line 63 class DisputesQueryFilter < CheckoutSdk::Common::DateRangeQueryFilter attr_accessor :limit, :skip, :id, :statuses, :payment_id, :payment_reference, :payment_arn, :this_channel_only, :entity_ids, :sub_entity_ids, :processing_channel_ids, :segment_ids, :payment_mcc end |
#payment_mcc ⇒ String?
The merchant category code (MCC) of the payment (ISO 18245).
- Optional
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/checkout_sdk/disputes/disputes_query_filter.rb', line 63 class DisputesQueryFilter < CheckoutSdk::Common::DateRangeQueryFilter attr_accessor :limit, :skip, :id, :statuses, :payment_id, :payment_reference, :payment_arn, :this_channel_only, :entity_ids, :sub_entity_ids, :processing_channel_ids, :segment_ids, :payment_mcc end |
#payment_reference ⇒ String?
An optional reference (such as an order ID) that identifies the payment.
- Optional
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/checkout_sdk/disputes/disputes_query_filter.rb', line 63 class DisputesQueryFilter < CheckoutSdk::Common::DateRangeQueryFilter attr_accessor :limit, :skip, :id, :statuses, :payment_id, :payment_reference, :payment_arn, :this_channel_only, :entity_ids, :sub_entity_ids, :processing_channel_ids, :segment_ids, :payment_mcc end |
#processing_channel_ids ⇒ String?
One or more comma-separated processing channel IDs. Works like a logical OR.
- Optional
-
Example: “pc_uzm3uxtssvmuxnyrfdffcyjxeu,pc_hy5wtzwzeuwefmsnjtdhw4scfi”
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/checkout_sdk/disputes/disputes_query_filter.rb', line 63 class DisputesQueryFilter < CheckoutSdk::Common::DateRangeQueryFilter attr_accessor :limit, :skip, :id, :statuses, :payment_id, :payment_reference, :payment_arn, :this_channel_only, :entity_ids, :sub_entity_ids, :processing_channel_ids, :segment_ids, :payment_mcc end |
#segment_ids ⇒ String?
One or more comma-separated segment IDs. Works like a logical OR.
- Optional
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/checkout_sdk/disputes/disputes_query_filter.rb', line 63 class DisputesQueryFilter < CheckoutSdk::Common::DateRangeQueryFilter attr_accessor :limit, :skip, :id, :statuses, :payment_id, :payment_reference, :payment_arn, :this_channel_only, :entity_ids, :sub_entity_ids, :processing_channel_ids, :segment_ids, :payment_mcc end |
#skip ⇒ Integer?
The number of results to skip.
- Optional
-
min 0, default 0
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/checkout_sdk/disputes/disputes_query_filter.rb', line 63 class DisputesQueryFilter < CheckoutSdk::Common::DateRangeQueryFilter attr_accessor :limit, :skip, :id, :statuses, :payment_id, :payment_reference, :payment_arn, :this_channel_only, :entity_ids, :sub_entity_ids, :processing_channel_ids, :segment_ids, :payment_mcc end |
#statuses ⇒ String?
One or more comma-separated statuses to filter by. Works like a logical OR.
- Optional
-
Example: “evidence_required,evidence_under_review”
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/checkout_sdk/disputes/disputes_query_filter.rb', line 63 class DisputesQueryFilter < CheckoutSdk::Common::DateRangeQueryFilter attr_accessor :limit, :skip, :id, :statuses, :payment_id, :payment_reference, :payment_arn, :this_channel_only, :entity_ids, :sub_entity_ids, :processing_channel_ids, :segment_ids, :payment_mcc end |
#sub_entity_ids ⇒ String?
One or more comma-separated sub-entity IDs. Works like a logical OR.
- Optional
-
Example: “ent_uzm3uxtssvmuxnyrfdffcyjxeu,ent_hy5wtzwzeuwefmsnjtdhw4scfi”
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/checkout_sdk/disputes/disputes_query_filter.rb', line 63 class DisputesQueryFilter < CheckoutSdk::Common::DateRangeQueryFilter attr_accessor :limit, :skip, :id, :statuses, :payment_id, :payment_reference, :payment_arn, :this_channel_only, :entity_ids, :sub_entity_ids, :processing_channel_ids, :segment_ids, :payment_mcc end |
#this_channel_only ⇒ TrueClass, ...
If true, only returns disputes for the channel associated with the secret key.
- Optional
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/checkout_sdk/disputes/disputes_query_filter.rb', line 63 class DisputesQueryFilter < CheckoutSdk::Common::DateRangeQueryFilter attr_accessor :limit, :skip, :id, :statuses, :payment_id, :payment_reference, :payment_arn, :this_channel_only, :entity_ids, :sub_entity_ids, :processing_channel_ids, :segment_ids, :payment_mcc end |