Class: CheckoutSdk::Identities::FaceAuthentication::FaceAuthenticationClient
- Inherits:
-
Client
- Object
- Client
- CheckoutSdk::Identities::FaceAuthentication::FaceAuthenticationClient
- Defined in:
- lib/checkout_sdk/identities/face_authentication/face_authentication_client.rb
Overview
Client for the Identities — Face Authentication API.
Instance Attribute Summary
Attributes inherited from Client
#api_client, #authorization_type, #configuration
Instance Method Summary collapse
- #anonymize_face_authentication(face_authentication_id) ⇒ Object
- #create_face_authentication(request) ⇒ Object
-
#create_face_authentication_attempt(face_authentication_id, attempt_request) ⇒ Object
Create a new attempt for an existing face authentication.
- #get_face_authentication(face_authentication_id) ⇒ Object
- #get_face_authentication_attempt(face_authentication_id, attempt_id) ⇒ Object
-
#get_face_authentication_attempt_assets(face_authentication_id, attempt_id, query = nil) ⇒ Object
Retrieve the assets (face images and videos) captured during a face authentication attempt.
- #get_face_authentication_attempts(face_authentication_id) ⇒ Object
-
#initialize(api_client, configuration) ⇒ FaceAuthenticationClient
constructor
A new instance of FaceAuthenticationClient.
Constructor Details
#initialize(api_client, configuration) ⇒ FaceAuthenticationClient
Returns a new instance of FaceAuthenticationClient.
16 17 18 |
# File 'lib/checkout_sdk/identities/face_authentication/face_authentication_client.rb', line 16 def initialize(api_client, configuration) super(api_client, configuration, CheckoutSdk::AuthorizationType::SECRET_KEY_OR_OAUTH) end |
Instance Method Details
#anonymize_face_authentication(face_authentication_id) ⇒ Object
32 33 34 35 36 37 |
# File 'lib/checkout_sdk/identities/face_authentication/face_authentication_client.rb', line 32 def anonymize_face_authentication(face_authentication_id) api_client.invoke_post( build_path(FACE_AUTHENTICATIONS, face_authentication_id, ANONYMIZE), ) end |
#create_face_authentication(request) ⇒ Object
21 22 23 |
# File 'lib/checkout_sdk/identities/face_authentication/face_authentication_client.rb', line 21 def create_face_authentication(request) api_client.invoke_post(FACE_AUTHENTICATIONS, , request) end |
#create_face_authentication_attempt(face_authentication_id, attempt_request) ⇒ Object
Create a new attempt for an existing face authentication.
42 43 44 45 46 47 48 |
# File 'lib/checkout_sdk/identities/face_authentication/face_authentication_client.rb', line 42 def create_face_authentication_attempt(face_authentication_id, attempt_request) api_client.invoke_post( build_path(FACE_AUTHENTICATIONS, face_authentication_id, ATTEMPTS), , attempt_request ) end |
#get_face_authentication(face_authentication_id) ⇒ Object
26 27 28 29 |
# File 'lib/checkout_sdk/identities/face_authentication/face_authentication_client.rb', line 26 def get_face_authentication(face_authentication_id) api_client.invoke_get(build_path(FACE_AUTHENTICATIONS, face_authentication_id), ) end |
#get_face_authentication_attempt(face_authentication_id, attempt_id) ⇒ Object
60 61 62 63 64 65 |
# File 'lib/checkout_sdk/identities/face_authentication/face_authentication_client.rb', line 60 def get_face_authentication_attempt(face_authentication_id, attempt_id) api_client.invoke_get( build_path(FACE_AUTHENTICATIONS, face_authentication_id, ATTEMPTS, attempt_id), ) end |
#get_face_authentication_attempt_assets(face_authentication_id, attempt_id, query = nil) ⇒ Object
Retrieve the assets (face images and videos) captured during a face authentication attempt.
72 73 74 75 76 77 78 |
# File 'lib/checkout_sdk/identities/face_authentication/face_authentication_client.rb', line 72 def get_face_authentication_attempt_assets(face_authentication_id, attempt_id, query = nil) api_client.invoke_get( build_path(FACE_AUTHENTICATIONS, face_authentication_id, ATTEMPTS, attempt_id, ASSETS), , query ) end |
#get_face_authentication_attempts(face_authentication_id) ⇒ Object
51 52 53 54 55 56 |
# File 'lib/checkout_sdk/identities/face_authentication/face_authentication_client.rb', line 51 def get_face_authentication_attempts(face_authentication_id) api_client.invoke_get( build_path(FACE_AUTHENTICATIONS, face_authentication_id, ATTEMPTS), ) end |