Class: CheckoutSdk::Identities::IdentityVerification::IdentityVerificationClient

Inherits:
Client
  • Object
show all
Defined in:
lib/checkout_sdk/identities/identity_verification/identity_verification_client.rb

Overview

Client for the Identities — Identity Verification API.

Instance Attribute Summary

Attributes inherited from Client

#api_client, #authorization_type, #configuration

Instance Method Summary collapse

Constructor Details

#initialize(api_client, configuration) ⇒ IdentityVerificationClient

Returns a new instance of IdentityVerificationClient.

Parameters:



17
18
19
# File 'lib/checkout_sdk/identities/identity_verification/identity_verification_client.rb', line 17

def initialize(api_client, configuration)
  super(api_client, configuration, CheckoutSdk::AuthorizationType::SECRET_KEY_OR_OAUTH)
end

Instance Method Details

#anonymize_identity_verification(identity_verification_id) ⇒ Object

Parameters:

  • identity_verification_id (String)


39
40
41
42
43
44
# File 'lib/checkout_sdk/identities/identity_verification/identity_verification_client.rb', line 39

def anonymize_identity_verification(identity_verification_id)
  api_client.invoke_post(
    build_path(IDENTITY_VERIFICATIONS, identity_verification_id, ANONYMIZE),
    sdk_authorization
  )
end

#create_and_open_idv(request) ⇒ Object

Create an identity verification and immediately receive its hosted URL.

Parameters:



23
24
25
# File 'lib/checkout_sdk/identities/identity_verification/identity_verification_client.rb', line 23

def create_and_open_idv(request)
  api_client.invoke_post(CREATE_AND_OPEN_IDV, sdk_authorization, request)
end

#create_identity_verification(request) ⇒ Object

Parameters:



28
29
30
# File 'lib/checkout_sdk/identities/identity_verification/identity_verification_client.rb', line 28

def create_identity_verification(request)
  api_client.invoke_post(IDENTITY_VERIFICATIONS, sdk_authorization, request)
end

#create_identity_verification_attempt(identity_verification_id, attempt_request) ⇒ Object

Create a new attempt for an existing identity verification.

Parameters:



49
50
51
52
53
54
55
# File 'lib/checkout_sdk/identities/identity_verification/identity_verification_client.rb', line 49

def create_identity_verification_attempt(identity_verification_id, attempt_request)
  api_client.invoke_post(
    build_path(IDENTITY_VERIFICATIONS, identity_verification_id, ATTEMPTS),
    sdk_authorization,
    attempt_request
  )
end

#get_identity_verification(identity_verification_id) ⇒ Object

Parameters:

  • identity_verification_id (String)


33
34
35
36
# File 'lib/checkout_sdk/identities/identity_verification/identity_verification_client.rb', line 33

def get_identity_verification(identity_verification_id)
  api_client.invoke_get(build_path(IDENTITY_VERIFICATIONS, identity_verification_id),
                        sdk_authorization)
end

#get_identity_verification_attempt(identity_verification_id, attempt_id) ⇒ Object

Parameters:

  • identity_verification_id (String)
  • attempt_id (String)


67
68
69
70
71
72
# File 'lib/checkout_sdk/identities/identity_verification/identity_verification_client.rb', line 67

def get_identity_verification_attempt(identity_verification_id, attempt_id)
  api_client.invoke_get(
    build_path(IDENTITY_VERIFICATIONS, identity_verification_id, ATTEMPTS, attempt_id),
    sdk_authorization
  )
end

#get_identity_verification_attempts(identity_verification_id) ⇒ Object

Parameters:

  • identity_verification_id (String)


58
59
60
61
62
63
# File 'lib/checkout_sdk/identities/identity_verification/identity_verification_client.rb', line 58

def get_identity_verification_attempts(identity_verification_id)
  api_client.invoke_get(
    build_path(IDENTITY_VERIFICATIONS, identity_verification_id, ATTEMPTS),
    sdk_authorization
  )
end

#get_identity_verification_pdf_report(identity_verification_id) ⇒ Object

Parameters:

  • identity_verification_id (String)


75
76
77
78
79
80
# File 'lib/checkout_sdk/identities/identity_verification/identity_verification_client.rb', line 75

def get_identity_verification_pdf_report(identity_verification_id)
  api_client.invoke_get(
    build_path(IDENTITY_VERIFICATIONS, identity_verification_id, PDF_REPORT),
    sdk_authorization
  )
end