Class: CheckoutSdk::Issuing::AmendDisputeRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/checkout_sdk/issuing/amend_dispute_request.rb

Overview

Request body for POST /issuing/disputes/disputeId/amend. Submit an amendment to a dispute that is currently blocked from proceeding. Maps swagger amend-dispute-request. All fields are optional.

Instance Attribute Summary collapse

Instance Attribute Details

#action_responseString

Returns Free-form text explaining your choices or asking questions about the requested changes. Max 1000 characters.

Returns:

  • (String)

    Free-form text explaining your choices or asking questions about the requested changes. Max 1000 characters.



26
27
28
29
# File 'lib/checkout_sdk/issuing/amend_dispute_request.rb', line 26

class AmendDisputeRequest
  attr_accessor :reason, :amount, :evidence, :fraud_details,
                :reason_change_justification, :action_response
end

#amountNumeric

Returns The updated disputed amount, in the minor unit of the transaction currency. If not provided, the existing amount is retained.

Returns:

  • (Numeric)

    The updated disputed amount, in the minor unit of the transaction currency. If not provided, the existing amount is retained.



26
27
28
29
# File 'lib/checkout_sdk/issuing/amend_dispute_request.rb', line 26

class AmendDisputeRequest
  attr_accessor :reason, :amount, :evidence, :fraud_details,
                :reason_change_justification, :action_response
end

#evidenceArray<Hash>

Returns Evidence supporting the dispute (maps IssuingDisputeEvidence).

Returns:

  • (Array<Hash>)

    Evidence supporting the dispute (maps IssuingDisputeEvidence).



26
27
28
29
# File 'lib/checkout_sdk/issuing/amend_dispute_request.rb', line 26

class AmendDisputeRequest
  attr_accessor :reason, :amount, :evidence, :fraud_details,
                :reason_change_justification, :action_response
end

#fraud_detailsIssuingDisputeFraudDetails

Returns Fraud-related details. Required if reason specifies a fraud-related dispute.

Returns:



26
27
28
29
# File 'lib/checkout_sdk/issuing/amend_dispute_request.rb', line 26

class AmendDisputeRequest
  attr_accessor :reason, :amount, :evidence, :fraud_details,
                :reason_change_justification, :action_response
end

#reasonString

Returns The updated four-digit scheme-specific reason code. If not provided, the existing reason code is retained.

Returns:

  • (String)

    The updated four-digit scheme-specific reason code. If not provided, the existing reason code is retained.



26
27
28
29
# File 'lib/checkout_sdk/issuing/amend_dispute_request.rb', line 26

class AmendDisputeRequest
  attr_accessor :reason, :amount, :evidence, :fraud_details,
                :reason_change_justification, :action_response
end

#reason_change_justificationString

Returns Justification for changing the reason at the escalation stage. Max 13000 characters.

Returns:

  • (String)

    Justification for changing the reason at the escalation stage. Max 13000 characters.



26
27
28
29
# File 'lib/checkout_sdk/issuing/amend_dispute_request.rb', line 26

class AmendDisputeRequest
  attr_accessor :reason, :amount, :evidence, :fraud_details,
                :reason_change_justification, :action_response
end