Class: CheckoutSdk::Issuing::IssuingDisputeFraudDetails
- Inherits:
-
Object
- Object
- CheckoutSdk::Issuing::IssuingDisputeFraudDetails
- Defined in:
- lib/checkout_sdk/issuing/issuing_dispute_fraud_details.rb
Overview
Fraud-related information required when the dispute reason code is fraud-related.
Maps swagger IssuingDisputeFraudDetails. Reused by create, escalate and amend dispute
requests.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional free-form description of the fraud.
-
#fraud_type ⇒ String
IssuingDisputeFraudType The type of fraud the cardholder is asserting.
Instance Attribute Details
#description ⇒ String
Returns Optional free-form description of the fraud.
14 15 16 |
# File 'lib/checkout_sdk/issuing/issuing_dispute_fraud_details.rb', line 14 class IssuingDisputeFraudDetails attr_accessor :fraud_type, :description end |
#fraud_type ⇒ String
Returns CheckoutSdk::Issuing::IssuingDisputeFraudType The type of fraud the cardholder is asserting. [Required].
14 15 16 |
# File 'lib/checkout_sdk/issuing/issuing_dispute_fraud_details.rb', line 14 class IssuingDisputeFraudDetails attr_accessor :fraud_type, :description end |