Class: CheckoutSdk::Issuing::SubmitDisputeRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/checkout_sdk/issuing/submit_dispute_request.rb

Overview

Request body for POST /issuing/disputes/disputeId/submit. Maps swagger submit-dispute-request. All fields are optional.

Instance Attribute Summary collapse

Instance Attribute Details

#amountNumeric

Returns The updated disputed amount, in the minor unit of the transaction currency. If not provided, the existing disputed amount is used.

Returns:

  • (Numeric)

    The updated disputed amount, in the minor unit of the transaction currency. If not provided, the existing disputed amount is used.



17
18
19
# File 'lib/checkout_sdk/issuing/submit_dispute_request.rb', line 17

class SubmitDisputeRequest
  attr_accessor :reason, :evidence, :amount
end

#evidenceArray<Hash>

Returns Evidence for the chargeback, if updated since you created the dispute (maps IssuingDisputeEvidence).

Returns:

  • (Array<Hash>)

    Evidence for the chargeback, if updated since you created the dispute (maps IssuingDisputeEvidence).



17
18
19
# File 'lib/checkout_sdk/issuing/submit_dispute_request.rb', line 17

class SubmitDisputeRequest
  attr_accessor :reason, :evidence, :amount
end

#reasonString

Returns The updated four-digit scheme-specific reason code. If not provided, the existing reason code is used.

Returns:

  • (String)

    The updated four-digit scheme-specific reason code. If not provided, the existing reason code is used.



17
18
19
# File 'lib/checkout_sdk/issuing/submit_dispute_request.rb', line 17

class SubmitDisputeRequest
  attr_accessor :reason, :evidence, :amount
end