Class: CheckoutSdk::Payments::BacsPaymentMethod

Inherits:
Object
  • Object
show all
Defined in:
lib/checkout_sdk/payments/setups/bacs_payment_method.rb

Overview

Bacs payment method configuration on a Payment Setup. Maps swagger Bacs.

Instance Attribute Summary collapse

Instance Attribute Details

#account_holderHash

Returns The account holder details (type, first_name, last_name, company_name, email).

Returns:

  • (Hash)

    The account holder details (type, first_name, last_name, company_name, email).



28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/checkout_sdk/payments/setups/bacs_payment_method.rb', line 28

class BacsPaymentMethod
  attr_accessor :status,
                :flags,
                :initialization,
                :instrument_id,
                :account_holder,
                :account_number,
                :bank_code,
                :country,
                :currency,
                :allow_partial_match
end

#account_numberString

Returns The account number of the Bacs Direct Debit account.

Returns:

  • (String)

    The account number of the Bacs Direct Debit account.



28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/checkout_sdk/payments/setups/bacs_payment_method.rb', line 28

class BacsPaymentMethod
  attr_accessor :status,
                :flags,
                :initialization,
                :instrument_id,
                :account_holder,
                :account_number,
                :bank_code,
                :country,
                :currency,
                :allow_partial_match
end

#allow_partial_matchTrueClass, FalseClass

Returns Whether to allow a partial match of the account holder details.

Returns:

  • (TrueClass, FalseClass)

    Whether to allow a partial match of the account holder details.



28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/checkout_sdk/payments/setups/bacs_payment_method.rb', line 28

class BacsPaymentMethod
  attr_accessor :status,
                :flags,
                :initialization,
                :instrument_id,
                :account_holder,
                :account_number,
                :bank_code,
                :country,
                :currency,
                :allow_partial_match
end

#bank_codeString

Returns The bank code (sort code) of the Bacs Direct Debit account.

Returns:

  • (String)

    The bank code (sort code) of the Bacs Direct Debit account.



28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/checkout_sdk/payments/setups/bacs_payment_method.rb', line 28

class BacsPaymentMethod
  attr_accessor :status,
                :flags,
                :initialization,
                :instrument_id,
                :account_holder,
                :account_number,
                :bank_code,
                :country,
                :currency,
                :allow_partial_match
end

#countryString

Returns Common::Country.

Returns:



28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/checkout_sdk/payments/setups/bacs_payment_method.rb', line 28

class BacsPaymentMethod
  attr_accessor :status,
                :flags,
                :initialization,
                :instrument_id,
                :account_holder,
                :account_number,
                :bank_code,
                :country,
                :currency,
                :allow_partial_match
end

#currencyString

Returns Common::Currency.

Returns:



28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/checkout_sdk/payments/setups/bacs_payment_method.rb', line 28

class BacsPaymentMethod
  attr_accessor :status,
                :flags,
                :initialization,
                :instrument_id,
                :account_holder,
                :account_number,
                :bank_code,
                :country,
                :currency,
                :allow_partial_match
end

#flagsArray(String)

Returns (response-only) Diagnostic flags returned by the API.

Returns:

  • (Array(String))

    (response-only) Diagnostic flags returned by the API.



28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/checkout_sdk/payments/setups/bacs_payment_method.rb', line 28

class BacsPaymentMethod
  attr_accessor :status,
                :flags,
                :initialization,
                :instrument_id,
                :account_holder,
                :account_number,
                :bank_code,
                :country,
                :currency,
                :allow_partial_match
end

#initializationString

Returns The initialization type for the payment method.

Returns:

  • (String)

    The initialization type for the payment method.



28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/checkout_sdk/payments/setups/bacs_payment_method.rb', line 28

class BacsPaymentMethod
  attr_accessor :status,
                :flags,
                :initialization,
                :instrument_id,
                :account_holder,
                :account_number,
                :bank_code,
                :country,
                :currency,
                :allow_partial_match
end

#instrument_idString

Returns (response-only) The ID of the Bacs instrument used for the payment.

Returns:

  • (String)

    (response-only) The ID of the Bacs instrument used for the payment.



28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/checkout_sdk/payments/setups/bacs_payment_method.rb', line 28

class BacsPaymentMethod
  attr_accessor :status,
                :flags,
                :initialization,
                :instrument_id,
                :account_holder,
                :account_number,
                :bank_code,
                :country,
                :currency,
                :allow_partial_match
end

#statusString

Returns (response-only) Payment method status.

Returns:

  • (String)

    (response-only) Payment method status.



28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/checkout_sdk/payments/setups/bacs_payment_method.rb', line 28

class BacsPaymentMethod
  attr_accessor :status,
                :flags,
                :initialization,
                :instrument_id,
                :account_holder,
                :account_number,
                :bank_code,
                :country,
                :currency,
                :allow_partial_match
end