Class: CheckoutSdk::Payments::CardPresentPaymentMethod

Inherits:
Object
  • Object
show all
Defined in:
lib/checkout_sdk/payments/setups/card_present_payment_method.rb

Overview

Card Present payment method configuration on a Payment Setup. Maps swagger CardPresent.

Instance Attribute Summary collapse

Instance Attribute Details

#emvString

Returns The EMV data read from the card or device.

Returns:

  • (String)

    The EMV data read from the card or device.



24
25
26
27
28
29
30
31
32
33
# File 'lib/checkout_sdk/payments/setups/card_present_payment_method.rb', line 24

class CardPresentPaymentMethod
  attr_accessor :status,
                :flags,
                :track2,
                :emv,
                :entry_mode,
                :pin,
                :store_for_future_use,
                :name
end

#entry_modeString

Returns The mode used to capture the card details at the point of sale.

Returns:

  • (String)

    The mode used to capture the card details at the point of sale.



24
25
26
27
28
29
30
31
32
33
# File 'lib/checkout_sdk/payments/setups/card_present_payment_method.rb', line 24

class CardPresentPaymentMethod
  attr_accessor :status,
                :flags,
                :track2,
                :emv,
                :entry_mode,
                :pin,
                :store_for_future_use,
                :name
end

#flagsArray(String)

Returns (response-only) Diagnostic flags returned by the API.

Returns:

  • (Array(String))

    (response-only) Diagnostic flags returned by the API.



24
25
26
27
28
29
30
31
32
33
# File 'lib/checkout_sdk/payments/setups/card_present_payment_method.rb', line 24

class CardPresentPaymentMethod
  attr_accessor :status,
                :flags,
                :track2,
                :emv,
                :entry_mode,
                :pin,
                :store_for_future_use,
                :name
end

#nameString

Returns The cardholder name.

Returns:

  • (String)

    The cardholder name.



24
25
26
27
28
29
30
31
32
33
# File 'lib/checkout_sdk/payments/setups/card_present_payment_method.rb', line 24

class CardPresentPaymentMethod
  attr_accessor :status,
                :flags,
                :track2,
                :emv,
                :entry_mode,
                :pin,
                :store_for_future_use,
                :name
end

#pinHash

Returns The encrypted PIN block details (key_set_id, block, block_format).

Returns:

  • (Hash)

    The encrypted PIN block details (key_set_id, block, block_format).



24
25
26
27
28
29
30
31
32
33
# File 'lib/checkout_sdk/payments/setups/card_present_payment_method.rb', line 24

class CardPresentPaymentMethod
  attr_accessor :status,
                :flags,
                :track2,
                :emv,
                :entry_mode,
                :pin,
                :store_for_future_use,
                :name
end

#statusString

Returns (response-only) Payment method status.

Returns:

  • (String)

    (response-only) Payment method status.



24
25
26
27
28
29
30
31
32
33
# File 'lib/checkout_sdk/payments/setups/card_present_payment_method.rb', line 24

class CardPresentPaymentMethod
  attr_accessor :status,
                :flags,
                :track2,
                :emv,
                :entry_mode,
                :pin,
                :store_for_future_use,
                :name
end

#store_for_future_useTrueClass, FalseClass

Returns Set to true if you intend to reuse the payment credentials in subsequent payments.

Returns:

  • (TrueClass, FalseClass)

    Set to true if you intend to reuse the payment credentials in subsequent payments.



24
25
26
27
28
29
30
31
32
33
# File 'lib/checkout_sdk/payments/setups/card_present_payment_method.rb', line 24

class CardPresentPaymentMethod
  attr_accessor :status,
                :flags,
                :track2,
                :emv,
                :entry_mode,
                :pin,
                :store_for_future_use,
                :name
end

#track2String

Returns The Track 2 data read from card or device.

Returns:

  • (String)

    The Track 2 data read from card or device.



24
25
26
27
28
29
30
31
32
33
# File 'lib/checkout_sdk/payments/setups/card_present_payment_method.rb', line 24

class CardPresentPaymentMethod
  attr_accessor :status,
                :flags,
                :track2,
                :emv,
                :entry_mode,
                :pin,
                :store_for_future_use,
                :name
end