Class: CheckoutSdk::Payments::PayByBankPaymentMethod

Inherits:
Object
  • Object
show all
Defined in:
lib/checkout_sdk/payments/setups/pay_by_bank_payment_method.rb

Overview

Pay by Bank (Open Banking) payment method configuration on a Payment Setup. Maps swagger PayByBank.

Instance Attribute Summary collapse

Instance Attribute Details

#actionHash

Returns (response-only) The next available action for the payment method (type, banks).

Returns:

  • (Hash)

    (response-only) The next available action for the payment method (type, banks).



17
18
19
20
21
22
# File 'lib/checkout_sdk/payments/setups/pay_by_bank_payment_method.rb', line 17

class PayByBankPaymentMethod
  attr_accessor :status,
                :flags,
                :bank_id,
                :action
end

#bank_idString

Returns The identifier of the bank the customer has selected for the payment.

Returns:

  • (String)

    The identifier of the bank the customer has selected for the payment.



17
18
19
20
21
22
# File 'lib/checkout_sdk/payments/setups/pay_by_bank_payment_method.rb', line 17

class PayByBankPaymentMethod
  attr_accessor :status,
                :flags,
                :bank_id,
                :action
end

#flagsArray(String)

Returns (response-only) Diagnostic flags returned by the API.

Returns:

  • (Array(String))

    (response-only) Diagnostic flags returned by the API.



17
18
19
20
21
22
# File 'lib/checkout_sdk/payments/setups/pay_by_bank_payment_method.rb', line 17

class PayByBankPaymentMethod
  attr_accessor :status,
                :flags,
                :bank_id,
                :action
end

#statusString

Returns (response-only) Payment method status.

Returns:

  • (String)

    (response-only) Payment method status.



17
18
19
20
21
22
# File 'lib/checkout_sdk/payments/setups/pay_by_bank_payment_method.rb', line 17

class PayByBankPaymentMethod
  attr_accessor :status,
                :flags,
                :bank_id,
                :action
end