Class: CheckoutSdk::Payments::PaymentPlan

Inherits:
Object
  • Object
show all
Defined in:
lib/checkout_sdk/payments/payment_plan.rb

Overview

Details of a recurring subscription or installment plan associated with a payment.

Instance Attribute Summary collapse

Instance Attribute Details

#amountInteger

Returns The amount to charge for each payment in the plan, in the minor currency unit. Required when source.type is “blik”, amount_variability is “Fixed”, and the recurring agreement is created without an initial payment (amount set to 0).

Returns:

  • (Integer)

    The amount to charge for each payment in the plan, in the minor currency unit. Required when source.type is “blik”, amount_variability is “Fixed”, and the recurring agreement is created without an initial payment (amount set to 0).



31
32
33
34
35
36
37
38
39
40
41
# File 'lib/checkout_sdk/payments/payment_plan.rb', line 31

class PaymentPlan
  attr_accessor :amount_variability,
                :financing,
                :amount,
                :days_between_payments,
                :total_number_of_payments,
                :current_payment_number,
                :expiry,
                :name,
                :start_date
end

#amount_variabilityString

Returns Recurring-only. One of “Fixed” or “Variable”.

Returns:

  • (String)

    Recurring-only. One of “Fixed” or “Variable”.



31
32
33
34
35
36
37
38
39
40
41
# File 'lib/checkout_sdk/payments/payment_plan.rb', line 31

class PaymentPlan
  attr_accessor :amount_variability,
                :financing,
                :amount,
                :days_between_payments,
                :total_number_of_payments,
                :current_payment_number,
                :expiry,
                :name,
                :start_date
end

#current_payment_numberInteger

Returns:

  • (Integer)


31
32
33
34
35
36
37
38
39
40
41
# File 'lib/checkout_sdk/payments/payment_plan.rb', line 31

class PaymentPlan
  attr_accessor :amount_variability,
                :financing,
                :amount,
                :days_between_payments,
                :total_number_of_payments,
                :current_payment_number,
                :expiry,
                :name,
                :start_date
end

#days_between_paymentsInteger

Returns:

  • (Integer)


31
32
33
34
35
36
37
38
39
40
41
# File 'lib/checkout_sdk/payments/payment_plan.rb', line 31

class PaymentPlan
  attr_accessor :amount_variability,
                :financing,
                :amount,
                :days_between_payments,
                :total_number_of_payments,
                :current_payment_number,
                :expiry,
                :name,
                :start_date
end

#expiryString

Returns ISO 8601 date-time.

Returns:

  • (String)

    ISO 8601 date-time



31
32
33
34
35
36
37
38
39
40
41
# File 'lib/checkout_sdk/payments/payment_plan.rb', line 31

class PaymentPlan
  attr_accessor :amount_variability,
                :financing,
                :amount,
                :days_between_payments,
                :total_number_of_payments,
                :current_payment_number,
                :expiry,
                :name,
                :start_date
end

#financingTrueClass, FalseClass

Returns Installment-only.

Returns:

  • (TrueClass, FalseClass)

    Installment-only.



31
32
33
34
35
36
37
38
39
40
41
# File 'lib/checkout_sdk/payments/payment_plan.rb', line 31

class PaymentPlan
  attr_accessor :amount_variability,
                :financing,
                :amount,
                :days_between_payments,
                :total_number_of_payments,
                :current_payment_number,
                :expiry,
                :name,
                :start_date
end

#nameString

Returns The name of the payment plan. Required when source.type is “blik”. For Blik merchant-initiated requests using an external partner_agreement_id, this value is used as the Blik Alias Label. Max 35 characters.

Returns:

  • (String)

    The name of the payment plan. Required when source.type is “blik”. For Blik merchant-initiated requests using an external partner_agreement_id, this value is used as the Blik Alias Label. Max 35 characters.



31
32
33
34
35
36
37
38
39
40
41
# File 'lib/checkout_sdk/payments/payment_plan.rb', line 31

class PaymentPlan
  attr_accessor :amount_variability,
                :financing,
                :amount,
                :days_between_payments,
                :total_number_of_payments,
                :current_payment_number,
                :expiry,
                :name,
                :start_date
end

#start_dateString

Returns The date on which the first payment will be taken, in YYYYMMDD format. Required when source.type is “blik” and the recurring agreement is created without an initial payment (amount set to 0).

Returns:

  • (String)

    The date on which the first payment will be taken, in YYYYMMDD format. Required when source.type is “blik” and the recurring agreement is created without an initial payment (amount set to 0).



31
32
33
34
35
36
37
38
39
40
41
# File 'lib/checkout_sdk/payments/payment_plan.rb', line 31

class PaymentPlan
  attr_accessor :amount_variability,
                :financing,
                :amount,
                :days_between_payments,
                :total_number_of_payments,
                :current_payment_number,
                :expiry,
                :name,
                :start_date
end

#total_number_of_paymentsInteger

Returns:

  • (Integer)


31
32
33
34
35
36
37
38
39
40
41
# File 'lib/checkout_sdk/payments/payment_plan.rb', line 31

class PaymentPlan
  attr_accessor :amount_variability,
                :financing,
                :amount,
                :days_between_payments,
                :total_number_of_payments,
                :current_payment_number,
                :expiry,
                :name,
                :start_date
end