Class: CheckoutSdk::Payments::ProcessingData

Inherits:
Object
  • Object
show all
Defined in:
lib/checkout_sdk/payments/processing_data.rb

Overview

Response-side processing object returned alongside payment responses. Distinct from ProcessingSettings which is the request-side equivalent.

Mirrors the swagger ProcessingData schema, referenced by PaymentDetails.processing (GET /payments/id).

Instance Attribute Summary collapse

Instance Attribute Details

#accommodation_dataArray<AccommodationData>

Returns [Optional] Contains information about the accommodation booked by the customer.

Returns:

  • (Array<AccommodationData>)

    [Optional] Contains information about the accommodation booked by the customer.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#aftBoolean

Returns [Optional] Indicates whether the payment is an Account Funding Transaction.

Returns:

  • (Boolean)

    [Optional] Indicates whether the payment is an Account Funding Transaction.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#airline_dataArray<AirlineData>

Returns [Optional] Contains information about the airline ticket and flights booked by the customer.

Returns:

  • (Array<AirlineData>)

    [Optional] Contains information about the airline ticket and flights booked by the customer.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#app_idString

Returns [Optional] The customer's application identifier.

Returns:

  • (String)

    [Optional] The customer's application identifier.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#custom_payment_method_idsArray<String>

Returns [Optional] An array defining which of the configured payment options within a payment category (for example, pay_later or pay_over_time) should be displayed for this purchase.

Returns:

  • (Array<String>)

    [Optional] An array defining which of the configured payment options within a payment category (for example, pay_later or pay_over_time) should be displayed for this purchase.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#failure_codeString

Returns [Optional] A high-level failure category returned by the payment provider when a payment is declined or fails. Not all payment methods return this field.

Returns:

  • (String)

    [Optional] A high-level failure category returned by the payment provider when a payment is declined or fails. Not all payment methods return this field.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#fallback_source_usedBoolean

Returns [Optional] Indicates whether the fallback_source field was used for the payment.

Returns:

  • (Boolean)

    [Optional] Indicates whether the fallback_source field was used for the payment.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#localeString

Returns [Optional] The language and region of the customer. ISO 639-2 language code, its value consists of language-country. Pattern: ^[a-z]2(?:-[A-Z][a-z]3)?(?:-(?:[A-Z]2))?$ - min 2 characters, max 10 characters.

Returns:

  • (String)

    [Optional] The language and region of the customer. ISO 639-2 language code, its value consists of language-country. Pattern: ^[a-z]2(?:-[A-Z][a-z]3)?(?:-(?:[A-Z]2))?$ - min 2 characters, max 10 characters



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#merchant_category_codeString

Returns [Optional] Four-digit code for retail financial services expressed in ISO 18245 format, classifying the types of goods or services you provide.

Returns:

  • (String)

    [Optional] Four-digit code for retail financial services expressed in ISO 18245 format, classifying the types of goods or services you provide.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#pan_type_processedString

Returns [Optional] The type of Primary Account Number (PAN) used for the payment. DPAN indicates a network token was used, FPAN indicates the full card was used. Enum: "fpan" "dpan".

Returns:

  • (String)

    [Optional] The type of Primary Account Number (PAN) used for the payment. DPAN indicates a network token was used, FPAN indicates the full card was used. Enum: "fpan" "dpan"



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#partner_authorization_codeString

Returns [Optional] Authorization code provided by partner.

Returns:

  • (String)

    [Optional] Authorization code provided by partner.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#partner_authorization_response_codeString

Returns [Optional] Authorization response code provided by partner.

Returns:

  • (String)

    [Optional] Authorization response code provided by partner.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#partner_codeString

[Optional] The 6-digit partner code returned by the payment provider. Returned when source.type is blik. Pattern: ^\d6$ - 6 characters

Returns:

  • (String)

    [Optional] The 6-digit partner code returned by the payment provider. Returned when source.type is blik. Pattern: ^\d6$ - 6 characters



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#partner_customer_idString

Returns [Optional] The customer's ID on the partner platform.

Returns:

  • (String)

    [Optional] The customer's ID on the partner platform.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#partner_error_codesArray<String>

Returns [Optional] The list of error codes that led the payment to fail or be declined, as given by the payment provider.

Returns:

  • (Array<String>)

    [Optional] The list of error codes that led the payment to fail or be declined, as given by the payment provider.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#partner_error_messageString

Returns [Optional] Error description provided by partner.

Returns:

  • (String)

    [Optional] Error description provided by partner.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#partner_fraud_statusString

Returns [Optional] Partner fraud status. If the status is Pending, and the merchant captures before it changes to Accepted, the risk of the transaction is solely on the merchant.

Returns:

  • (String)

    [Optional] Partner fraud status. If the status is Pending, and the merchant captures before it changes to Accepted, the risk of the transaction is solely on the merchant.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#partner_merchant_advice_codeString

Returns [Optional] The Mastercard Merchant Advice Code (MAC), which contains additional information about the transaction. For declined transactions it also indicates whether the payment can be retried and how long to wait.

Returns:

  • (String)

    [Optional] The Mastercard Merchant Advice Code (MAC), which contains additional information about the transaction. For declined transactions it also indicates whether the payment can be retried and how long to wait.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#partner_order_idString

Returns [Optional] The Klarna order ID associated with the payment.

Returns:

  • (String)

    [Optional] The Klarna order ID associated with the payment.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#partner_payment_idString

Returns [Optional] The partner-originated unique payment identifier.

Returns:

  • (String)

    [Optional] The partner-originated unique payment identifier.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#partner_response_codeString

Returns [Optional] The raw response code returned by the payment provider when a payment is declined or fails. Not all payment methods return this field.

Returns:

  • (String)

    [Optional] The raw response code returned by the payment provider when a payment is declined or fails. Not all payment methods return this field.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#partner_statusString

Returns [Optional] Status of a payment provided by partner.

Returns:

  • (String)

    [Optional] Status of a payment provided by partner.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#partner_transaction_idString

Returns [Optional] Unique transaction identification provided by partner.

Returns:

  • (String)

    [Optional] Unique transaction identification provided by partner.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#preferred_schemeString

Returns [Optional] The preferred scheme for co-badged card payment processing. If performing 3DS via a third party, this is the scheme that processed 3DS. Does not support PINless debit schemes in the US (STAR, PULSE, NYCE, ACCEL, SHAZAM). Enum: "mastercard" "visa" "cartes_bancaires".

Returns:

  • (String)

    [Optional] The preferred scheme for co-badged card payment processing. If performing 3DS via a third party, this is the scheme that processed 3DS. Does not support PINless debit schemes in the US (STAR, PULSE, NYCE, ACCEL, SHAZAM). Enum: "mastercard" "visa" "cartes_bancaires"



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#retrieval_reference_numberString

Returns [Optional] A unique identifier for the authorization provided by partner.

Returns:

  • (String)

    [Optional] A unique identifier for the authorization provided by partner.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#schemeString

Returns [Optional] The scheme on which the payment was authorized. This may differ from the card's scheme used for the payment if the card is co-badged and the payment was authorized on a different network. Read-only.

Returns:

  • (String)

    [Optional] The scheme on which the payment was authorized. This may differ from the card's scheme used for the payment if the card is co-badged and the payment was authorized on a different network. Read-only.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#scheme_merchant_idString

Returns [Optional] The merchant identifier that was configured with the scheme and used for the payment.

Returns:

  • (String)

    [Optional] The merchant identifier that was configured with the scheme and used for the payment.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

Returns [Optional] The scheme transaction link identifier. Returned for Mastercard transactions when the scheme provides a link identifier that ties together related transactions on the network.

Returns:

  • (String)

    [Optional] The scheme transaction link identifier. Returned for Mastercard transactions when the scheme provides a link identifier that ties together related transactions on the network.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end

#tax_amountNumeric

Returns [Optional] Total tax amount of the order.

Returns:

  • (Numeric)

    [Optional] Total tax amount of the order.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/checkout_sdk/payments/processing_data.rb', line 96

class ProcessingData
  attr_accessor :preferred_scheme,
                :app_id,
                :partner_customer_id,
                :partner_payment_id,
                :tax_amount,
                :locale,
                :retrieval_reference_number,
                :partner_order_id,
                :partner_status,
                :partner_transaction_id,
                :partner_error_codes,
                :partner_error_message,
                :partner_authorization_code,
                :partner_authorization_response_code,
                :partner_fraud_status,
                :partner_merchant_advice_code,
                :custom_payment_method_ids,
                :aft,
                :merchant_category_code,
                :scheme_merchant_id,
                :pan_type_processed,
                :fallback_source_used,
                :failure_code,
                :partner_code,
                :partner_response_code,
                :scheme,
                :accommodation_data,
                :airline_data,
                :scheme_transaction_link_id
end