Class: CheckoutSdk::Previous::CheckoutPreviousStaticKeysSdkBuilder
- Inherits:
-
StaticKeysBuilder
- Object
- AbstractCheckoutSdkBuilder
- StaticKeysBuilder
- CheckoutSdk::Previous::CheckoutPreviousStaticKeysSdkBuilder
- Defined in:
- lib/checkout_sdk/previous/checkout_previous_static_keys_sdk_builder.rb
Instance Attribute Summary
Attributes inherited from StaticKeysBuilder
Attributes inherited from AbstractCheckoutSdkBuilder
#environment, #http_client, #logger, #multipart_http_client, #subdomain
Instance Method Summary collapse
- #build ⇒ Object
-
#requires_environment_subdomain? ⇒ Boolean
The Previous (ABC) platform predates merchant-specific subdomains, so it is exempt from the mandatory with_environment_subdomain/with_legacy_domain configuration.
Methods inherited from StaticKeysBuilder
#with_public_key, #with_secret_key
Methods inherited from AbstractCheckoutSdkBuilder
#environment_subdomain, #initialize, #with_environment, #with_environment_subdomain, #with_http_client, #with_legacy_domain, #with_logger, #with_multipart_http_client
Constructor Details
This class inherits a constructor from CheckoutSdk::AbstractCheckoutSdkBuilder
Instance Method Details
#build ⇒ Object
16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 |
# File 'lib/checkout_sdk/previous/checkout_previous_static_keys_sdk_builder.rb', line 16 def build @secret_key_pattern = SECRET_KEY_PATTERN @public_key_pattern = PUBLIC_KEY_PATTERN super configuration = CheckoutConfiguration.new( PreviousStaticKeysSdkCredentials.new(secret_key, public_key), environment, http_client, multipart_http_client, logger ) env_subdomain = environment_subdomain configuration.environment_subdomain = env_subdomain if env_subdomain CheckoutApi.new(configuration) end |
#requires_environment_subdomain? ⇒ Boolean
The Previous (ABC) platform predates merchant-specific subdomains, so it is exempt from the mandatory with_environment_subdomain/with_legacy_domain configuration.
12 13 14 |
# File 'lib/checkout_sdk/previous/checkout_previous_static_keys_sdk_builder.rb', line 12 def requires_environment_subdomain? false end |