Class: CheckoutSdk::Sessions::GoogleSpa

Inherits:
Object
  • Object
show all
Defined in:
lib/checkout_sdk/sessions/google_spa.rb

Overview

This object contains the Google SPA properties (non-hosted only).

Instance Attribute Summary collapse

Instance Attribute Details

#continue_urlString

Returns Fully qualified URL for redirecting the user's browser session after authentication. For example, this field may be the merchant's website for purchase confirmation once payment is complete. Required if in full redirect (not iframe) mode.

Returns:

  • (String)

    Fully qualified URL for redirecting the user's browser session after authentication. For example, this field may be the merchant's website for purchase confirmation once payment is complete. Required if in full redirect (not iframe) mode.



11
12
13
# File 'lib/checkout_sdk/sessions/google_spa.rb', line 11

class GoogleSpa
  attr_accessor :continue_url
end