Class: CheckoutSdk::Accounts::AgreedTerms
- Inherits:
-
Object
- Object
- CheckoutSdk::Accounts::AgreedTerms
- Defined in:
- lib/checkout_sdk/accounts/agreed_terms.rb
Overview
The terms of service the sub-entity agreed to (Accounts API v3.0, SaaS onboarding).
Instance Attribute Summary collapse
-
#date ⇒ String
Date and time the terms were agreed (RFC 3339 / ISO 8601).
-
#email ⇒ String
Email address of the person who agreed to the terms.
-
#ip_address ⇒ String
IP address (IPv4 or IPv6) of the person at the time they agreed.
-
#name ⇒ String
First and last name of the person who agreed to the terms.
-
#version ⇒ String
Identifier of the terms version that was agreed.
Instance Attribute Details
#date ⇒ String
Returns Date and time the terms were agreed (RFC 3339 / ISO 8601).
16 17 18 19 20 21 22 |
# File 'lib/checkout_sdk/accounts/agreed_terms.rb', line 16 class AgreedTerms attr_accessor :date, :ip_address, :name, :email, :version end |
#email ⇒ String
Returns Email address of the person who agreed to the terms.
16 17 18 19 20 21 22 |
# File 'lib/checkout_sdk/accounts/agreed_terms.rb', line 16 class AgreedTerms attr_accessor :date, :ip_address, :name, :email, :version end |
#ip_address ⇒ String
Returns IP address (IPv4 or IPv6) of the person at the time they agreed.
16 17 18 19 20 21 22 |
# File 'lib/checkout_sdk/accounts/agreed_terms.rb', line 16 class AgreedTerms attr_accessor :date, :ip_address, :name, :email, :version end |
#name ⇒ String
Returns First and last name of the person who agreed to the terms.
16 17 18 19 20 21 22 |
# File 'lib/checkout_sdk/accounts/agreed_terms.rb', line 16 class AgreedTerms attr_accessor :date, :ip_address, :name, :email, :version end |
#version ⇒ String
Returns Identifier of the terms version that was agreed.
16 17 18 19 20 21 22 |
# File 'lib/checkout_sdk/accounts/agreed_terms.rb', line 16 class AgreedTerms attr_accessor :date, :ip_address, :name, :email, :version end |