Class: CheckoutSdk::Accounts::Citizenship
- Inherits:
-
Object
- Object
- CheckoutSdk::Accounts::Citizenship
- Defined in:
- lib/checkout_sdk/accounts/citizenship.rb
Overview
A citizenship or legal status held by a company representative (Accounts API v3.0).
Instance Attribute Summary collapse
-
#country ⇒ String
Common::Country two-letter ISO 3166-1 alpha-2 code.
-
#type ⇒ String
The type of citizenship or legal status (e.g.
citizenship,residency).
Instance Attribute Details
#country ⇒ String
Returns Common::Country two-letter ISO 3166-1 alpha-2 code.
10 11 12 13 |
# File 'lib/checkout_sdk/accounts/citizenship.rb', line 10 class Citizenship attr_accessor :type, :country end |
#type ⇒ String
Returns The type of citizenship or legal status (e.g. citizenship, residency).
10 11 12 13 |
# File 'lib/checkout_sdk/accounts/citizenship.rb', line 10 class Citizenship attr_accessor :type, :country end |