Class: CheckoutSdk::Accounts::OnboardEntity
- Inherits:
-
Object
- Object
- CheckoutSdk::Accounts::OnboardEntity
- Defined in:
- lib/checkout_sdk/accounts/onboard_entity.rb
Instance Attribute Summary collapse
- #additional_info ⇒ AdditionalInfo
-
#agreed_terms ⇒ AgreedTerms
Details of the person who agreed to the terms and conditions (Accounts API v3.0 SaaS onboarding).
- #company ⇒ Company
- #contact_details ⇒ ContactDetails
- #documents ⇒ OnboardSubEntityDocuments
- #individual ⇒ Individual
- #is_draft ⇒ Boolean
- #processing_details ⇒ ProcessingDetails
- #profile ⇒ Profile
- #reference ⇒ String
-
#seller_category ⇒ String
Identifier of a seller category configured on the platform during onboarding.
-
#submitter ⇒ Submitter
Captures evidence of the end-user's consent to onboarding.
Instance Attribute Details
#additional_info ⇒ AdditionalInfo
32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32 class OnboardEntity attr_accessor :reference, :is_draft, :profile, :contact_details, :company, :processing_details, :individual, :documents, :additional_info, :seller_category, :agreed_terms, :submitter end |
#agreed_terms ⇒ AgreedTerms
Returns Details of the person who agreed to the terms and conditions (Accounts API v3.0 SaaS onboarding).
32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32 class OnboardEntity attr_accessor :reference, :is_draft, :profile, :contact_details, :company, :processing_details, :individual, :documents, :additional_info, :seller_category, :agreed_terms, :submitter end |
#company ⇒ Company
32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32 class OnboardEntity attr_accessor :reference, :is_draft, :profile, :contact_details, :company, :processing_details, :individual, :documents, :additional_info, :seller_category, :agreed_terms, :submitter end |
#contact_details ⇒ ContactDetails
32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32 class OnboardEntity attr_accessor :reference, :is_draft, :profile, :contact_details, :company, :processing_details, :individual, :documents, :additional_info, :seller_category, :agreed_terms, :submitter end |
#documents ⇒ OnboardSubEntityDocuments
32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32 class OnboardEntity attr_accessor :reference, :is_draft, :profile, :contact_details, :company, :processing_details, :individual, :documents, :additional_info, :seller_category, :agreed_terms, :submitter end |
#individual ⇒ Individual
32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32 class OnboardEntity attr_accessor :reference, :is_draft, :profile, :contact_details, :company, :processing_details, :individual, :documents, :additional_info, :seller_category, :agreed_terms, :submitter end |
#is_draft ⇒ Boolean
32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32 class OnboardEntity attr_accessor :reference, :is_draft, :profile, :contact_details, :company, :processing_details, :individual, :documents, :additional_info, :seller_category, :agreed_terms, :submitter end |
#processing_details ⇒ ProcessingDetails
32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32 class OnboardEntity attr_accessor :reference, :is_draft, :profile, :contact_details, :company, :processing_details, :individual, :documents, :additional_info, :seller_category, :agreed_terms, :submitter end |
#profile ⇒ Profile
32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32 class OnboardEntity attr_accessor :reference, :is_draft, :profile, :contact_details, :company, :processing_details, :individual, :documents, :additional_info, :seller_category, :agreed_terms, :submitter end |
#reference ⇒ String
32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32 class OnboardEntity attr_accessor :reference, :is_draft, :profile, :contact_details, :company, :processing_details, :individual, :documents, :additional_info, :seller_category, :agreed_terms, :submitter end |
#seller_category ⇒ String
Returns Identifier of a seller category configured on the platform during onboarding. Used for US ISV onboarding variants.
32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32 class OnboardEntity attr_accessor :reference, :is_draft, :profile, :contact_details, :company, :processing_details, :individual, :documents, :additional_info, :seller_category, :agreed_terms, :submitter end |
#submitter ⇒ Submitter
Returns Captures evidence of the end-user's consent to onboarding. Used for US ISV onboarding variants.
32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/checkout_sdk/accounts/onboard_entity.rb', line 32 class OnboardEntity attr_accessor :reference, :is_draft, :profile, :contact_details, :company, :processing_details, :individual, :documents, :additional_info, :seller_category, :agreed_terms, :submitter end |