Class: CheckoutSdk::Accounts::ScheduleFrequencyMonthly
- Inherits:
-
ScheduleRequest
- Object
- ScheduleRequest
- CheckoutSdk::Accounts::ScheduleFrequencyMonthly
- Defined in:
- lib/checkout_sdk/accounts/schedule_frequency_monthly.rb
Instance Attribute Summary collapse
-
#by_month_day ⇒ Array(Integer)
The day or days of the month the payout should take place.
Attributes inherited from ScheduleRequest
Instance Method Summary collapse
-
#initialize ⇒ ScheduleFrequencyMonthly
constructor
A new instance of ScheduleFrequencyMonthly.
Constructor Details
#initialize ⇒ ScheduleFrequencyMonthly
Returns a new instance of ScheduleFrequencyMonthly.
12 13 14 |
# File 'lib/checkout_sdk/accounts/schedule_frequency_monthly.rb', line 12 def initialize super(ScheduleFrequencyType::MONTHLY) end |
Instance Attribute Details
#by_month_day ⇒ Array(Integer)
Returns The day or days of the month the payout should take place. For SaaS sellers (ISV), only the following combinations are supported, in any order: [1], [15], [1, 15] or [1, 16].
9 10 11 12 13 14 15 |
# File 'lib/checkout_sdk/accounts/schedule_frequency_monthly.rb', line 9 class ScheduleFrequencyMonthly < ScheduleRequest attr_accessor :by_month_day def initialize super(ScheduleFrequencyType::MONTHLY) end end |