Class: CheckoutSdk::Payments::BacsPaymentMethod
- Inherits:
-
Object
- Object
- CheckoutSdk::Payments::BacsPaymentMethod
- Defined in:
- lib/checkout_sdk/payments/setups/bacs_payment_method.rb
Overview
Bacs payment method configuration on a Payment Setup. Maps swagger Bacs.
Instance Attribute Summary collapse
-
#account_holder ⇒ Hash
The account holder details (
type,first_name,last_name,company_name,email). -
#account_number ⇒ String
The account number of the Bacs Direct Debit account.
-
#allow_partial_match ⇒ TrueClass, FalseClass
Whether to allow a partial match of the account holder details.
-
#bank_code ⇒ String
The bank code (sort code) of the Bacs Direct Debit account.
- #country ⇒ String
- #currency ⇒ String
-
#flags ⇒ Array(String)
(response-only) Diagnostic flags returned by the API.
-
#initialization ⇒ String
The initialization type for the payment method.
-
#instrument_id ⇒ String
(response-only) The ID of the Bacs instrument used for the payment.
-
#status ⇒ String
(response-only) Payment method status.
Instance Attribute Details
#account_holder ⇒ Hash
Returns The account holder details (type, first_name, last_name,
company_name, email).
28 29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/checkout_sdk/payments/setups/bacs_payment_method.rb', line 28 class BacsPaymentMethod attr_accessor :status, :flags, :initialization, :instrument_id, :account_holder, :account_number, :bank_code, :country, :currency, :allow_partial_match end |
#account_number ⇒ String
Returns The account number of the Bacs Direct Debit account.
28 29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/checkout_sdk/payments/setups/bacs_payment_method.rb', line 28 class BacsPaymentMethod attr_accessor :status, :flags, :initialization, :instrument_id, :account_holder, :account_number, :bank_code, :country, :currency, :allow_partial_match end |
#allow_partial_match ⇒ TrueClass, FalseClass
Returns Whether to allow a partial match of the account holder details.
28 29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/checkout_sdk/payments/setups/bacs_payment_method.rb', line 28 class BacsPaymentMethod attr_accessor :status, :flags, :initialization, :instrument_id, :account_holder, :account_number, :bank_code, :country, :currency, :allow_partial_match end |
#bank_code ⇒ String
Returns The bank code (sort code) of the Bacs Direct Debit account.
28 29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/checkout_sdk/payments/setups/bacs_payment_method.rb', line 28 class BacsPaymentMethod attr_accessor :status, :flags, :initialization, :instrument_id, :account_holder, :account_number, :bank_code, :country, :currency, :allow_partial_match end |
#country ⇒ String
Returns Common::Country.
28 29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/checkout_sdk/payments/setups/bacs_payment_method.rb', line 28 class BacsPaymentMethod attr_accessor :status, :flags, :initialization, :instrument_id, :account_holder, :account_number, :bank_code, :country, :currency, :allow_partial_match end |
#currency ⇒ String
Returns Common::Currency.
28 29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/checkout_sdk/payments/setups/bacs_payment_method.rb', line 28 class BacsPaymentMethod attr_accessor :status, :flags, :initialization, :instrument_id, :account_holder, :account_number, :bank_code, :country, :currency, :allow_partial_match end |
#flags ⇒ Array(String)
Returns (response-only) Diagnostic flags returned by the API.
28 29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/checkout_sdk/payments/setups/bacs_payment_method.rb', line 28 class BacsPaymentMethod attr_accessor :status, :flags, :initialization, :instrument_id, :account_holder, :account_number, :bank_code, :country, :currency, :allow_partial_match end |
#initialization ⇒ String
Returns The initialization type for the payment method.
28 29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/checkout_sdk/payments/setups/bacs_payment_method.rb', line 28 class BacsPaymentMethod attr_accessor :status, :flags, :initialization, :instrument_id, :account_holder, :account_number, :bank_code, :country, :currency, :allow_partial_match end |
#instrument_id ⇒ String
Returns (response-only) The ID of the Bacs instrument used for the payment.
28 29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/checkout_sdk/payments/setups/bacs_payment_method.rb', line 28 class BacsPaymentMethod attr_accessor :status, :flags, :initialization, :instrument_id, :account_holder, :account_number, :bank_code, :country, :currency, :allow_partial_match end |
#status ⇒ String
Returns (response-only) Payment method status.
28 29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/checkout_sdk/payments/setups/bacs_payment_method.rb', line 28 class BacsPaymentMethod attr_accessor :status, :flags, :initialization, :instrument_id, :account_holder, :account_number, :bank_code, :country, :currency, :allow_partial_match end |