Class: CheckoutSdk::Payments::BlikSource
- Inherits:
-
PaymentSource
- Object
- PaymentSource
- CheckoutSdk::Payments::BlikSource
- Defined in:
- lib/checkout_sdk/payments/source/apm/blik_source.rb
Overview
Blik payment source for the /payments endpoint.
When source.type is “blik”:
- currency must be PLN
- amount must not exceed 5,000,000 (minor unit)
- reference is limited to 35 characters
For customer-initiated payments, provide the 6-digit BLIK code in ‘processing.partner_code`. For merchant-initiated recurring payments, use either source.type: “id” with a previous source.id, or source.type: “blik” with `partner_agreement_id`.
Instance Attribute Summary collapse
-
#id ⇒ String
(response-only) The Checkout.com source identifier for a partner agreement created during a Blik recurring payment.
-
#partner_agreement_id ⇒ String
The Blik PAYID identifying an external partner agreement created with another PSP.
Attributes inherited from PaymentSource
Instance Method Summary collapse
-
#initialize ⇒ BlikSource
constructor
A new instance of BlikSource.
Constructor Details
#initialize ⇒ BlikSource
Returns a new instance of BlikSource.
26 27 28 |
# File 'lib/checkout_sdk/payments/source/apm/blik_source.rb', line 26 def initialize super(CheckoutSdk::Common::PaymentSourceType::BLIK) end |
Instance Attribute Details
#id ⇒ String
Returns (response-only) The Checkout.com source identifier for a partner agreement created during a Blik recurring payment.
22 23 24 25 26 27 28 29 |
# File 'lib/checkout_sdk/payments/source/apm/blik_source.rb', line 22 class BlikSource < PaymentSource attr_accessor :id, :partner_agreement_id def initialize super(CheckoutSdk::Common::PaymentSourceType::BLIK) end end |
#partner_agreement_id ⇒ String
Returns The Blik PAYID identifying an external partner agreement created with another PSP.
22 23 24 25 26 27 28 29 |
# File 'lib/checkout_sdk/payments/source/apm/blik_source.rb', line 22 class BlikSource < PaymentSource attr_accessor :id, :partner_agreement_id def initialize super(CheckoutSdk::Common::PaymentSourceType::BLIK) end end |