Class: CheckoutSdk::Payments::CardPresentPaymentMethod
- Inherits:
-
Object
- Object
- CheckoutSdk::Payments::CardPresentPaymentMethod
- Defined in:
- lib/checkout_sdk/payments/setups/card_present_payment_method.rb
Overview
Card Present payment method configuration on a Payment Setup. Maps swagger CardPresent.
Instance Attribute Summary collapse
-
#emv ⇒ String
The EMV data read from the card or device.
-
#entry_mode ⇒ String
The mode used to capture the card details at the point of sale.
-
#flags ⇒ Array(String)
(response-only) Diagnostic flags returned by the API.
-
#name ⇒ String
The cardholder name.
-
#pin ⇒ Hash
The encrypted PIN block details (
key_set_id,block,block_format). -
#status ⇒ String
(response-only) Payment method status.
-
#store_for_future_use ⇒ TrueClass, FalseClass
Set to
trueif you intend to reuse the payment credentials in subsequent payments. -
#track2 ⇒ String
The Track 2 data read from card or device.
Instance Attribute Details
#emv ⇒ String
Returns The EMV data read from the card or device.
24 25 26 27 28 29 30 31 32 33 |
# File 'lib/checkout_sdk/payments/setups/card_present_payment_method.rb', line 24 class CardPresentPaymentMethod attr_accessor :status, :flags, :track2, :emv, :entry_mode, :pin, :store_for_future_use, :name end |
#entry_mode ⇒ String
Returns The mode used to capture the card details at the point of sale.
24 25 26 27 28 29 30 31 32 33 |
# File 'lib/checkout_sdk/payments/setups/card_present_payment_method.rb', line 24 class CardPresentPaymentMethod attr_accessor :status, :flags, :track2, :emv, :entry_mode, :pin, :store_for_future_use, :name end |
#flags ⇒ Array(String)
Returns (response-only) Diagnostic flags returned by the API.
24 25 26 27 28 29 30 31 32 33 |
# File 'lib/checkout_sdk/payments/setups/card_present_payment_method.rb', line 24 class CardPresentPaymentMethod attr_accessor :status, :flags, :track2, :emv, :entry_mode, :pin, :store_for_future_use, :name end |
#name ⇒ String
Returns The cardholder name.
24 25 26 27 28 29 30 31 32 33 |
# File 'lib/checkout_sdk/payments/setups/card_present_payment_method.rb', line 24 class CardPresentPaymentMethod attr_accessor :status, :flags, :track2, :emv, :entry_mode, :pin, :store_for_future_use, :name end |
#pin ⇒ Hash
Returns The encrypted PIN block details (key_set_id, block, block_format).
24 25 26 27 28 29 30 31 32 33 |
# File 'lib/checkout_sdk/payments/setups/card_present_payment_method.rb', line 24 class CardPresentPaymentMethod attr_accessor :status, :flags, :track2, :emv, :entry_mode, :pin, :store_for_future_use, :name end |
#status ⇒ String
Returns (response-only) Payment method status.
24 25 26 27 28 29 30 31 32 33 |
# File 'lib/checkout_sdk/payments/setups/card_present_payment_method.rb', line 24 class CardPresentPaymentMethod attr_accessor :status, :flags, :track2, :emv, :entry_mode, :pin, :store_for_future_use, :name end |
#store_for_future_use ⇒ TrueClass, FalseClass
Returns Set to true if you intend to reuse the payment credentials
in subsequent payments.
24 25 26 27 28 29 30 31 32 33 |
# File 'lib/checkout_sdk/payments/setups/card_present_payment_method.rb', line 24 class CardPresentPaymentMethod attr_accessor :status, :flags, :track2, :emv, :entry_mode, :pin, :store_for_future_use, :name end |
#track2 ⇒ String
Returns The Track 2 data read from card or device.
24 25 26 27 28 29 30 31 32 33 |
# File 'lib/checkout_sdk/payments/setups/card_present_payment_method.rb', line 24 class CardPresentPaymentMethod attr_accessor :status, :flags, :track2, :emv, :entry_mode, :pin, :store_for_future_use, :name end |