Class: CheckoutSdk::Payments::PayByBankPaymentMethod
- Inherits:
-
Object
- Object
- CheckoutSdk::Payments::PayByBankPaymentMethod
- Defined in:
- lib/checkout_sdk/payments/setups/pay_by_bank_payment_method.rb
Overview
Pay by Bank (Open Banking) payment method configuration on a Payment Setup.
Maps swagger PayByBank.
Instance Attribute Summary collapse
-
#action ⇒ Hash
(response-only) The next available action for the payment method (
type,banks). -
#bank_id ⇒ String
The identifier of the bank the customer has selected for the payment.
-
#flags ⇒ Array(String)
(response-only) Diagnostic flags returned by the API.
-
#status ⇒ String
(response-only) Payment method status.
Instance Attribute Details
#action ⇒ Hash
Returns (response-only) The next available action for the payment method
(type, banks).
17 18 19 20 21 22 |
# File 'lib/checkout_sdk/payments/setups/pay_by_bank_payment_method.rb', line 17 class PayByBankPaymentMethod attr_accessor :status, :flags, :bank_id, :action end |
#bank_id ⇒ String
Returns The identifier of the bank the customer has selected for the payment.
17 18 19 20 21 22 |
# File 'lib/checkout_sdk/payments/setups/pay_by_bank_payment_method.rb', line 17 class PayByBankPaymentMethod attr_accessor :status, :flags, :bank_id, :action end |
#flags ⇒ Array(String)
Returns (response-only) Diagnostic flags returned by the API.
17 18 19 20 21 22 |
# File 'lib/checkout_sdk/payments/setups/pay_by_bank_payment_method.rb', line 17 class PayByBankPaymentMethod attr_accessor :status, :flags, :bank_id, :action end |
#status ⇒ String
Returns (response-only) Payment method status.
17 18 19 20 21 22 |
# File 'lib/checkout_sdk/payments/setups/pay_by_bank_payment_method.rb', line 17 class PayByBankPaymentMethod attr_accessor :status, :flags, :bank_id, :action end |